summaryrefslogtreecommitdiffstats
path: root/src/libs/engine/Driver.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libs/engine/Driver.h')
-rw-r--r--src/libs/engine/Driver.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/libs/engine/Driver.h b/src/libs/engine/Driver.h
index 5f452781..2fd17150 100644
--- a/src/libs/engine/Driver.h
+++ b/src/libs/engine/Driver.h
@@ -20,12 +20,12 @@
#include <string>
using std::string;
-namespace Om {
+namespace Ingen {
template <typename T> class DuplexPort;
/** Representation of a system (outside Om, ie hardware) audio port.
*
* This is the class through which the rest of the engine manages everything
* related to driver ports. Derived classes are expected to have a pointer to
@@ -107,6 +107,6 @@ public:
#endif
-} // namespace Om
+} // namespace Ingen
#endif // DRIVER_H
@@ -20,12 +20,12 @@
template <typename T> class DuplexPort;
-/** Representation of a system (outside Om, ie hardware) audio port.
+/** Representation of a "system" (eg outside Ingen) port.
*
* This is the class through which the rest of the engine manages everything